export function generateMap(source) {
    let col = 0;
    let row = 0;
    const map = {};
    for (const ch of source) {
        col++;
        if (ch === '\n') {
            row++;
            col = 0;
        }
        if (ch >= 'a' && ch <= 'z') {
            const record = map[ch] || [];
            record.push({ col, row });
            map[ch] = record;
        }
    }
    const geometry = {};
    for (const key in map) {
        const record = map[key];
        const x = record[0].col;
        const y = record[0].row;
        const w = record[3].col - x + 1;
        const h = record[3].row - y + 1;
        geometry[key] = [x, y, w, h];
    }
    return geometry;
}
export function dom(source) {
    const layoutMap = generateMap(source);
    const container = document.createElement('div');
    const domMap = {
        container,
    };
    for (const elementId in layoutMap) {
        const element = document.createElement('div');
        const geometry = layoutMap[elementId];
        element.id = elementId;
        element.style.position = 'absolute';
        element.style.left = `${geometry[0]}px`;
        element.style.top = `${geometry[1]}px`;
        element.style.width = `${geometry[2]}px`;
        element.style.height = `${geometry[3]}px`;
        container.appendChild(element);
        domMap[elementId] = element;
    }
    return domMap;
}
export function getLayoutFixture(source) {
    const fixture = dom(source);
    document.body.appendChild(fixture.container);
    after(function () {
        document.body.removeChild(fixture.container);
    });
    return fixture;
}
//# sourceMappingURL=layout-driver.js.map